@@ -214,12 +214,12 @@ class Project(object):
         try:
             # Try to pull out the project office comments about the run
             pos = self.project_office.runs[run]
-        except:
+        except (TypeError, IndexError):
             pos = None
         try:
             # Try to pull out the project office comments about the scans
             poo = self.project_office.scans[run]
-        except:
+        except (TypeError, IndexError):
             poo = []
         # Enforce that the number of project office scan comments match the
         # actual number of scans
@@ -333,24 +333,9 @@ class Project(object):
             raise IndexError("Invalid run index")
         
         self.runs[run].update()
-        self.runs[run].scans.sort()
-           
+        self.runs[run].scans.sort()   
         ses = self.runs[run]
-        try:
-            # Try to pull out the project office comments about the run
-            pos = self.project_office.runs[run]
-        except:
-            pos = None
-        try:
-            # Try to pull out the project office comments about the scans
-            poo = self.project_office.scans[run]
-        except:
-            poo = []
-        # Enforce that the number of project office scan comments match the
-        # actual number of scans
-        while (len(ses.scans) - len(poo)) > 0:
-            poo.append(None)
-            
+        
         # Build the SDFs
         ## Setup the common information
         start = mjdmpm_to_datetime(ses.scans[0].mjd, ses.scans[0].mpm)
@@ -1430,7 +1415,7 @@ def parse_idf(filename, verbose=False):
             # to deal with any indicies present
             try:
                 keywordSection, value = line.split(None, 1)
-            except:
+            except ValueError:
                 continue
             
             mtch = kwdRE.match(keywordSection)
