@@ -572,6 +572,11 @@ class AntennaArray(aipy.amp.AntennaArray):
     def __repr__(self):
         return str(self)
         
+    def __copy__(self):
+        result = AntennaArray((self.lat, self.lon, self.elev), self.ants)
+        result.__dict__.update(self.__dict__)
+        return result
+        
     def __reduce__(self):
         return (AntennaArray, ((self.lat, self.lon, self.elev), self.ants))
         
@@ -907,16 +912,14 @@ def build_sim_array(station, antennas, freq, jd=None, pos_error=0.0, force_flat=
     # Set the Julian Data for the AntennaArray object if it is provided.  The try...except
     # clause is used to deal with people who may want to pass an array of JDs in rather than
     # just one.  If one isn't provided, use the date set for the input 'station'.
-    if jd is not None:
-        try:
-            len(jd)
-        except:
-            simAA.set_jultime(jd)
-        else:
-            simAA.set_jultime(jd[0])
-    else:
+    if jd is None:
         simAA.date = station.date
-        
+    else:
+        try:
+            simAA.set_jultime(jd[0])
+        except TypeError:
+            simAA.set_jultime(jd)
+            
     return simAA
 
 
@@ -949,15 +952,15 @@ def __build_sim_data(aa, srcs, pols=['xx', 'yy', 'xy', 'yx'], jd=None, chan=None
         chanMax = chan[-1]
         
     # Update the JD if necessary
-    if jd is not None:
+    if jd is None:
+        jd = aa.get_jultime()
+    else:
         if verbose:
             if count is not None and max is not None:
                 print("Setting Julian Date to %.5f (%i of %i)" % (jd, count, max))
             else:
                 print("Setting Julian Date to %.5f" % jd)
         aa.set_jultime(jd)
-    else:
-        jd = aa.get_jultime()
     Gij_sf = aa.passband(0,1)
     def Bij_sf(xyz, pol):
         Bi = aa[0].bm_response(xyz, pol=pol[0]).transpose()
@@ -1043,7 +1046,7 @@ def __build_sim_data(aa, srcs, pols=['xx', 'yy', 'xy', 'yx'], jd=None, chan=None
     UVData = VisibilityDataSet(jd, freq, baselines, [], antennaarray=aa, phase_center=phase_center)
     
     # Go!
-    if phase_center is not 'z':
+    if phase_center != 'z':
         phase_center.compute(aa)
         pcAz = phase_center.az*180/numpy.pi
         pcEl = phase_center.alt*180/numpy.pi
@@ -1104,14 +1107,14 @@ def build_sim_data(aa, srcs, pols=['xx', 'yy', 'xy', 'yx'], jd=None, chan=None,
     """
     
     # Update the JD if necessary
-    if jd is not None:
+    if jd is None:
+        jd = [aa.get_jultime()]
+    else:
         try:
             len(jd)
         except TypeError:
             jd = [jd]
-    else:
-        jd = [aa.get_jultime()]
-        
+            
     # Build up output dictionary
     freq = aa.get_afreqs()*1e9
     if len(freq.shape) == 2:
@@ -1225,9 +1228,6 @@ def add_baseline_noise(dataSet, SEFD, tInt, bandwidth=None, efficiency=1.0):
         except IndexError:
             raise RuntimeError("Too few frequencies to determine the bandwidth, use the 'bandwidth' keyword")
             
-    # Calculate the standard deviation of the real/imaginary noise
-    visNoiseSigma = SEFD / efficiency / numpy.sqrt(2.0*bandwidth*tInt)
-    
     # Make sure that we have an SEFD for each antenna
     ants = []
     for i,j in dataSet.baselines:
@@ -1243,6 +1243,12 @@ def add_baseline_noise(dataSet, SEFD, tInt, bandwidth=None, efficiency=1.0):
     except TypeError:
         SEFD = numpy.ones(nAnts)*SEFD
         
+    # Calculate the standard deviation of the real/imaginary noise
+    visNoiseSigma = numpy.zeros((len(dataSet.baselines), len(dataSet.freq)))
+    for k,(i,j) in enumerate(dataSet.baselines):
+        visNoiseSigma[k,:] = numpy.sqrt(SEFD[i]*SEFD[j])
+    visNoiseSigma *= 1 / efficiency / numpy.sqrt(2.0*bandwidth*tInt)
+    
     # Build the VisibilityDataSet to hold the data with noise added
     bnData = dataSet.copy(include_pols=True)
     
