@@ -37,15 +37,13 @@ class measurementset_tests(unittest.TestCase):
     """A unittest.TestCase collection of unit tests for the lsl.writer.measurementset.Ms
     class."""
     
-    testPath = None
-    
     def setUp(self):
         """Turn off all numpy warnings and create the temporary file directory."""
        
         numpy.seterr(all='ignore')
         self.testPath = tempfile.mkdtemp(prefix='test-measurementset-', suffix='.tmp')
         
-    def __initData(self):
+    def _init_data(self):
         """Private function to generate a random set of data for writing a UVFITS
         file.  The data is returned as a dictionary with keys:
          * freq - frequency array in Hz
@@ -75,7 +73,7 @@ class measurementset_tests(unittest.TestCase):
         testFile = os.path.join(self.testPath, 'ms-test-W.ms')
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Start the table
         tbl = measurementset.Ms(testFile, ref_time=testTime)
@@ -99,7 +97,7 @@ class measurementset_tests(unittest.TestCase):
         testFile = os.path.join(self.testPath, 'ms-test-ERR.ms')
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         for i in range(4):
             # Start the file
@@ -121,7 +119,7 @@ class measurementset_tests(unittest.TestCase):
         testFile = os.path.join(self.testPath, 'ms-test-UV.ms')
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Start the file
         fits = measurementset.Ms(testFile, ref_time=testTime)
@@ -182,7 +180,7 @@ class measurementset_tests(unittest.TestCase):
         testFile = os.path.join(self.testPath, 'ms-test-MultiIF.ms')
         
         # Get some data
-        data = self.__initData()
+        data = self._init_data()
         
         # Start the file
         fits = measurementset.Ms(testFile, ref_time=testTime)
